@@ -36,6 +36,8 @@ module Data.Default (
     Default(..)
 ) where
 
+import Data.Int
+import Data.Word
 import Data.Monoid
 import Data.Ratio
 import Data.Complex
@@ -61,6 +63,15 @@ instance Default (Seq a) where def = mempty
 instance (Default a) => Default (Tree a) where def = Node def def
 
 instance Default Int where def = 0
+instance Default Int8 where def = 0
+instance Default Int16 where def = 0
+instance Default Int32 where def = 0
+instance Default Int64 where def = 0
+instance Default Word where def = 0
+instance Default Word8 where def = 0
+instance Default Word16 where def = 0
+instance Default Word32 where def = 0
+instance Default Word64 where def = 0
 instance Default Integer where def = 0
 instance Default Float where def = 0
 instance Default Double where def = 0
@@ -90,5 +101,7 @@ instance (Default a, Default b) => Default (a, b) where def = (def, def)
 instance (Default a, Default b, Default c) => Default (a, b, c) where def = (def, def, def)
 instance (Default a, Default b, Default c, Default d) => Default (a, b, c, d) where def = (def, def, def, def)
 instance (Default a, Default b, Default c, Default d, Default e) => Default (a, b, c, d, e) where def = (def, def, def, def, def)
+instance (Default a, Default b, Default c, Default d, Default e, Default f) => Default (a, b, c, d, e, f) where def = (def, def, def, def, def, def)
+instance (Default a, Default b, Default c, Default d, Default e, Default f, Default g) => Default (a, b, c, d, e, f, g) where def = (def, def, def, def, def, def, def)
 
 instance Default TimeLocale where def = defaultTimeLocale
